use bitfinex::positions::Position;

#[derive(Copy, Clone, Eq, PartialEq, Hash)]
pub enum PositionState {
    Critical,
    Loss,
    BreakEven,
    MinimumProfit,
    Profit,
    Any,
}

impl PositionState {
    fn color(self) -> String {
        match self {
            PositionState::Any => "blue",
            PositionState::Critical | PositionState::Loss => "red",
            PositionState::BreakEven => "yellow",
            PositionState::MinimumProfit | PositionState::Profit => "green",
        }
        .into()
    }
}

#[derive(Clone)]
pub struct PositionWrapper {
    position: Position,
    net_pl: f64,
    net_pl_perc: f64,
    state: Option<PositionState>,
}

impl PositionWrapper {
    pub fn new(
        position: Position,
        net_pl: f64,
        net_pl_perc: f64,
        state: Option<PositionState>,
    ) -> Self {
        PositionWrapper {
            position,
            net_pl,
            net_pl_perc,
            state,
        }
    }

    pub fn position(&self) -> &Position {
        &self.position
    }
    pub fn net_pl(&self) -> f64 {
        self.net_pl
    }
    pub fn net_pl_perc(&self) -> f64 {
        self.net_pl_perc
    }
    pub fn state(&self) -> Option<PositionState> {
        self.state
    }
}
